@@ -14,11 +14,11 @@ Template::Flute - Modern designer-friendly HTML templating Engine
 
 =head1 VERSION
 
-Version 0.0020
+Version 0.0021
 
 =cut
 
-our $VERSION = '0.0020';
+our $VERSION = '0.0021';
 
 =head1 SYNOPSIS
 
@@ -996,13 +996,20 @@ see L<Template::Flute::Filter::NobreakSingle>.
 =item currency
 
 Currency filter, see L<Template::Flute::Filter::Currency>.
+Requires L<Number::Format> module.
 
 =item date
 
 Date filter, see L<Template::Flute::Filter::Date>.
+Requires L<DateTime> and L<DateTime::Format::ISO8601> modules.
 
 =back
 
+Filter classes are loaded at runtime for efficiency and to keep the
+number of dependencies for Template::Flute as small as possible.
+
+See above for prerequisites needed by the included filter classes.
+
 =head1 INCLUDES
 
 Files, especially components for web pages can be processed and included
