@@ -266,11 +266,17 @@ sub parse_file {
 
 sub _parse_template {
 	my ($self, $template, $spec_object) = @_;
-	my ($twig, $xml, $object, $list, $html_content, $encoding);
+	my ($twig, %twig_args, $xml, $object, $list, $html_content, $encoding);
 
 	$object = {specs => {}, lists => {}, forms => {}, params => {}};
 		
-	$twig = new XML::Twig (twig_handlers => {_all_ => sub {$self->_parse_handler($_[1], $spec_object)}});
+	%twig_args = (twig_handlers => {_all_ => sub {$self->_parse_handler($_[1], $spec_object)}});
+
+	if ($XML::Twig::VERSION > 3.39) {
+	    $twig_args{output_html_doctype} = 1;
+	}
+	
+	$twig = new XML::Twig (%twig_args);
 
 	if (ref($template) eq 'SCALAR') {
 		$self->{file} = '';
@@ -396,6 +402,7 @@ sub _elt_handler {
 		
 		$self->{lists}->{$name} = new Template::Flute::List ($sob, [join(' ', @$static_classes)], $spec_object, $name);
 		$self->{lists}->{$name}->params_add($self->{params}->{$name}->{array});
+		$self->{lists}->{$name}->separators_add($self->{separators}->{$name}->{array});
 		$self->{lists}->{$name}->increments_add($self->{increments}->{$name}->{array});
 			
 		if (exists $sob->{iterator}) {
@@ -411,6 +418,19 @@ sub _elt_handler {
 		return $self;
 	}
 
+	if ($sob->{type} eq 'separator') {
+		push (@{$sob->{elts}}, $elt);
+		$self->_elt_indicate_replacements($sob, $elt, $gi, $name, $spec_object);
+
+		if (exists $self->{lists}->{$sob->{list}}) {
+		    $self->{lists}->{$sob->{list}}->separators_add([$sob]);
+		}
+		else {
+		    $self->{separators}->{$sob->{list}}->{hash}->{$name} = $sob;
+		    push(@{$self->{separators}->{$sob->{list}}->{array}}, $sob);
+		}
+	}
+
 	if (exists $sob->{list} && exists $self->{lists}->{$sob->{list}}) {
 		return $self;
 	}
@@ -443,6 +463,12 @@ sub _elt_handler {
 
 		$self->{params}->{$sob->{list} || $sob->{form}}->{hash}->{$name} = $sob;
 		push(@{$self->{params}->{$sob->{list} || $sob->{form}}->{array}}, $sob);
+	} elsif ($sob->{type} eq 'separator') {
+		push (@{$sob->{elts}}, $elt);
+		$self->_elt_indicate_replacements($sob, $elt, $gi, $name, $spec_object);
+
+		$self->{separators}->{$sob->{list}}->{hash}->{$name} = $sob;
+		push(@{$self->{separators}->{$sob->{list}}->{array}}, $sob);
 	} elsif ($sob->{type} eq 'value') {
 		push (@{$sob->{elts}}, $elt);
 
